Django Toolkit
==============

.. image:: https://travis-ci.org/luizalabs/django-toolkit.svg?branch=master
    :target: https://travis-ci.org/luizalabs/django-toolkit

.. image:: https://codecov.io/gh/luizalabs/django-toolkit/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/luizalabs/django-toolkit

Our set of tools to develop projects using the Django framework
